@@ -1,6 +1,4 @@
-from arkclient.format.stream import Stream
-from arkclient.format.header import Header
-from arkclient.lib.configuration import Ini
+from arklibrary import Stream, Header, Ini
 import socket
 from pathlib import Path
 
